@@ -40,6 +40,8 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, ProgramState):
             return obj.__dict__
+        elif isinstance(obj, TaskStatus):
+            return obj.__dict__
         else:
             return json.JSONEncoder.default(self, obj)
 
@@ -84,6 +86,8 @@ class JsonDecoder(json.JSONDecoder):
                 return ConfirmTask(**obj)
             if '_type' in obj and obj['_type'] == 'program_state':
                 return ProgramState(**obj)
+            if '_type' in obj and obj['_type'] == 'task_status':
+                return TaskStatus(**obj)
         return obj
 
 
