@@ -59,7 +59,7 @@ class Pose:
         return Pose(Vector3(pose[0], pose[1], pose[2]), Vector3(pose[3], pose[4], pose[5]), name=name)
 
     @staticmethod
-    def pose_trans(p1: 'Pose', p2: 'Pose') -> 'Pose':
+    def pose_trans(p1: 'Pose', p2: 'Pose', new_name: str = '') -> 'Pose':
         # from: https://forum.universal-robots.com/t/pose-trans-and-pose-inv-functions-in-urcap/1257 (scroll a bit down)
         res = Pose.matrix_multiply(p1.get_transform_matrix(), p2.get_transform_matrix())
 
@@ -68,10 +68,17 @@ class Pose:
             [res[1][0], res[1][1], res[1][2]],
             [res[2][0], res[2][1], res[2][2]]
         ])
+        if new_name:
+            name = new_name
+        elif p1.name:
+            name = p1.name
+        else:
+            name = p2.name
 
         return Pose(
             Vector3(res[0][3], res[1][3], res[2][3]),
-            angle.get_rotation_vector()
+            angle.get_rotation_vector(),
+            name
         )
 
     def get_transform_matrix(self):
